#
# spec file for package necpp
#
# Copyright (c) 2012 Wojciech Kazubski, wk@ire.pw.edu.pl
# Copyright (c) 2014 Torsten Duwe <duwe@suse.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

%define gitversion 20171105
Name:           necpp
Version:        1.7.4
Release:        lp150.1.7
Summary:        Numerical Electromagnetic Code in C++
License:        GPL-2.0+
Group:          Productivity/Hamradio/Other
Url:            http://elec.otago.ac.nz/w/index.php/Necpp
#Source0:        https://github.com/tmolteno/necpp/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source0:        %{name}-%{version}.git%{gitversion}.tar.gz
Source1:        yagi16.nec
Patch2:         necpp-Makefile-fix
Patch3:         Makefile.test-rpm-fix
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
%if 0%{?suse_version} >= 1310
BuildRequires:  lapack-devel
%endif
BuildRequires:  libtool
BuildRoot:      %{_tmppath}/build-root-%{name}

%description
This is a free (GPL) NEC-2 compatible electromagnetic code. It can both read
nec2 antenna description files (like the original) and also be incorporated into
other projects like GUI tools and automatic antenna optimization systems.
For a comprehensive overview of nec2 code base usage see www.nec2.org.

%package        devel
Summary:        Development files for nec2pp
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Provides:       pkgconfig(%{name})

%description    devel
This package contains development files for nec2pp.

%package     -n libnecpp0
Summary:        NEC2++ as a shared object
Group:          Development/Libraries/C and C++

%description -n libnecpp0
The nec2++ binary is often called by automatic antenna optimisers
repeatedly. The shared library allows dynamic linkage to all
nec2++ functions, avoiding the process creation overhead.

%prep
%setup -q -n %{name}
cp %{SOURCE1} testharness/data
%patch2 -p1
%patch3 -p1
%ifarch %ix86
%define atlas_sse_dir %( echo `rpm -qa | grep -o 'libatlas3-sse.*-devel' | grep -o 'sse.*[^devel]' | tr -d '-' | sed '/ssecommon/d'` )
sed -i 's|/usr/lib/atlas-base/atlas|\"%{_libdir}/atlas-%{atlas_sse_dir}\"|' configure.ac
%else
sed -i 's|/usr/lib/atlas-base/atlas|\"%{_libdir}/atlas\"|' configure.ac
%endif

%build
make -f Makefile.git
%if 0%{?suse_version} >= 1310
%configure --without-lapack
%else
%configure --without-lapack
%endif
make

%check
ln -sfn ../src testharness/bin
make -C testharness/FORTRAN >/dev/null 2>&1
cat testharness/Makefile
# make -C testharness/c_src
# Test disabled on Tumbleweed 
%if 0%{?suse_version} < 1330
make -C testharness test
%endif

%install
export QA_RPATHS=0x0002
make DESTDIR=%{buildroot} install
rm %{buildroot}%{_libdir}/*.la
rm %{buildroot}%{_libdir}/*.a

%clean
rm -rf %{buildroot}

%post -n libnecpp0 -p /sbin/ldconfig

%postun -n libnecpp0 -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_bindir}/nec2*
%doc AUTHORS COPYING CHANGELOG.md README.md NEWS TODO.md

%files -n libnecpp0
%defattr(-,root,root,-)
%{_libdir}/libnecpp.so.*

%files devel
%defattr(-,root,root,-)
%{_libdir}/libnecpp.so
%{_includedir}/libnecpp.h
%{_libdir}/pkgconfig/necpp.pc

%changelog
* Sun Dec  3 2017 wk@ire.pw.edu.pl
- updated to version 1.7.4 git 20171105
- patch necpp-atlas.patch removed (applied upstream)
- added missing file yasing file yagi16.nec
- test temporarly disabled om Tumbleweed
* Mon Jul 25 2016 wk@ire.pw.edu.pl
- updated to version 1.7.2b1
- patch necpp-atlas.patch split into two parts,
  * ncpp-atlas.patch and ncpp-atlas-configure.patch
  * to allow build on newer releases
* Tue Dec  2 2014 duwe@suse.com
- Activate test harness to verify program integrity
- only test against FORTRAN version, and only sane cases
  * Makefile.test-rpm-fix
- disable libatlas usage on older distributions
- fix Makefile to put -lm _after_ objects
  * necpp-Makefile-fix
* Thu Nov 27 2014 dmitry_r@opensuse.org
- Build with lapack and atlas support
  * necpp-atlas.patch
- Drop Fedora support
- spec file cleanup
* Thu Nov 27 2014 duwe@suse.com
- pulled from Wojciech Kazubski's home project
- updated to version 1.5.3
- split out shared library
* Sat Mar 23 2013 Wojciech Kazubski <wk@ire.pw.edu.pl>
- initial specfile
